default.default       {  glyph:  box;
                         label:  1;
                         bump:   +1;
                         height: 6;
                         color:  wheat;
                      }
translation           {}
similarity            {}
transcription         {}
experimental          {}
structural            {}
repeat.default        {
                         glyph:  ex;
                         height: 3
                         fillcolor: #FFE4C4;
                         color: #8B7D6B;
                      }
repeat.microsatellite {
                         glyph:  ex;
                         height: 3;
                         color: #6699CC;
                      }
repeat.inverted_repeat {
                         glyph:  ex;
                         height: 3;
                         color: #6699CC;
                      }
repeat.tandem_repeat  {
                         glyph:  ex;
                         height: 3;
                         color: #6699CC;
                      }
repeat.transposable_element {
                         glyph:  ex;
                         height: 3;
                         color: #6699CC;
                      }
repeat.LINE           {
                         glyph:  ex;
                         height: 3;
                         color: #6699CC;
                      }


miscellaneous         {}
trans-splice_acceptor {}
partial_gene          {}
